<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh">
<context>
    <name>ConfirmPassphraseDialog</name>
    <message>
        <source>Set Passphrase</source>
        <translation>设置口令</translation>
    </message>
    <message>
        <source>Leave blank when passphrase is not needed</source>
        <translation>如果不需要口令则留空</translation>
    </message>
    <message>
        <source>&amp;Passphrase:</source>
        <translation>口令(&amp;P)：</translation>
    </message>
    <message>
        <source>&amp;Confirmation:</source>
        <translation>确认口令(&amp;C)：</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>The confirmation passphrase does not match</source>
        <translation>两次输入的口令不一致</translation>
    </message>
</context>
<context>
    <name>FileEncryptionDialog</name>
    <message>
        <source>File Encryption</source>
        <translation>文件加密</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>命令</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>格式：</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>浏览……</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>输出文件：</translation>
    </message>
    <message>
        <source>Input file:</source>
        <translation>输入文件：</translation>
    </message>
    <message>
        <source>EncryptPad format</source>
        <translation>EncryptPad 格式</translation>
    </message>
    <message>
        <source>EPD</source>
        <translation>EPD</translation>
    </message>
    <message>
        <source>OpenPGP</source>
        <translation>OpenPGP</translation>
    </message>
    <message>
        <source>GPG</source>
        <translation>GPG</translation>
    </message>
    <message>
        <source>OpenPGP Armor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ASC</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key path</source>
        <translation>密钥路径</translation>
    </message>
    <message>
        <source>Key file path:</source>
        <translation>密钥文件路径：</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>选择……</translation>
    </message>
    <message>
        <source>Passphrase</source>
        <translation>口令</translation>
    </message>
    <message>
        <source>Passphrase:</source>
        <translation>口令：</translation>
    </message>
    <message>
        <source>Confirmation:</source>
        <translation>确认：</translation>
    </message>
    <message>
        <source>Parameters</source>
        <translation>参数</translation>
    </message>
    <message>
        <source>Parameters...</source>
        <translation>参数……</translation>
    </message>
    <message>
        <source>Encryption:</source>
        <translation>加密：</translation>
    </message>
    <message>
        <source>Encrypt</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>Decrypt</source>
        <translation>解密</translation>
    </message>
    <message>
        <source>SwitchDirection</source>
        <translation>SwitchDirection</translation>
    </message>
    <message>
        <source>IOChange</source>
        <translation>IOChange</translation>
    </message>
    <message>
        <source>Input File</source>
        <translation>输入文件</translation>
    </message>
    <message>
        <source>Output File</source>
        <translation>输出文件</translation>
    </message>
    <message>
        <source>EncryptPad</source>
        <translation>EncryptPad</translation>
    </message>
    <message>
        <source>Confirmation passphrase does not match.</source>
        <translation>两次输入的口令不一致。</translation>
    </message>
    <message>
        <source>%1 does not exist.</source>
        <translation>%1 不存在。</translation>
    </message>
    <message>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 已经存在。
你想要覆盖它吗？</translation>
    </message>
    <message>
        <source>Cannot open the encryption key</source>
        <translation>无法打开密钥</translation>
    </message>
    <message>
        <source>The encryption key is invalid</source>
        <translation>密钥不合法</translation>
    </message>
    <message>
        <source>Cannot download the encryption key. CURL tool is not found.</source>
        <translation>无法读取密钥：没有找到CURL工具。</translation>
    </message>
    <message>
        <source>Cannot download the key. CURL returned non zero exit code</source>
        <translation>无法读取密钥：CURL的返回值不为0（发生异常）。</translation>
    </message>
    <message>
        <source>Invalid passphrase for key file</source>
        <translation>对该密钥文件输入的口令不正确。</translation>
    </message>
    <message>
        <source>The job has been cancelled</source>
        <translation>任务已经被取消</translation>
    </message>
    <message>
        <source>File has been encrypted successfully.</source>
        <translation>文件已被成功加密。</translation>
    </message>
    <message>
        <source>File has been decrypted successfully.</source>
        <translation>文件已被成功解密。</translation>
    </message>
</context>
<context>
    <name>FileExtensions</name>
    <message>
        <source>ASCII-armored GnuPG (*.asc)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Plain Text (*.txt)</source>
        <translation>文本文件 (*.txt)</translation>
    </message>
    <message>
        <source>Encrypted Files (*.epd *.gpg *.asc);; Plain Text (*.txt)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key (*.key)</source>
        <translation>密钥文件 (*.key)</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>所有文件 (*)</translation>
    </message>
    <message>
        <source>All Files (*.*)</source>
        <translation>所有文件 (*.*)</translation>
    </message>
</context>
<context>
    <name>FilePropertiesDialog</name>
    <message>
        <source>File Properties</source>
        <translation>文件属性</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>算法：</translation>
    </message>
    <message>
        <source>Iterations:</source>
        <translation>迭代数：</translation>
    </message>
    <message>
        <source>Triple DES</source>
        <comment>2</comment>
        <translation>Triple DES</translation>
    </message>
    <message>
        <source>CAST5</source>
        <comment>3</comment>
        <translation>CAST5</translation>
    </message>
    <message>
        <source>AES-128</source>
        <comment>7</comment>
        <translation>AES-128</translation>
    </message>
    <message>
        <source>AES-256 (recommended)</source>
        <comment>9</comment>
        <translation>AES-256 (推荐)</translation>
    </message>
    <message>
        <source>Compression:</source>
        <translation>压缩：</translation>
    </message>
    <message>
        <source>ZIP</source>
        <comment>1</comment>
        <translation>ZIP</translation>
    </message>
    <message>
        <source>ZLIB</source>
        <comment>2</comment>
        <translation>ZLIB</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <comment>2</comment>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-256 (recommended)</source>
        <comment>8</comment>
        <translation>SHA-256 (推荐)</translation>
    </message>
    <message>
        <source>Salt:</source>
        <translation>加盐：</translation>
    </message>
    <message>
        <source>Hash:</source>
        <translation>哈希：</translation>
    </message>
    <message>
        <source>FFFFFFFFFFFFFFFF</source>
        <translation>FFFFFFFFFFFFFFFF</translation>
    </message>
    <message>
        <source>PropertyChanged</source>
        <translation>PropertyChanged</translation>
    </message>
    <message>
        <source>AES-256 (recommended)</source>
        <translation>AES-256 (推荐)</translation>
    </message>
    <message>
        <source>Uncompressed</source>
        <translation>不压缩</translation>
    </message>
</context>
<context>
    <name>FindAndReplace</name>
    <message>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message>
        <source>&amp;Replace with:</source>
        <translation>用于替换的值(&amp;R)：</translation>
    </message>
    <message>
        <source>&amp;Find:</source>
        <translation>查找(&amp;F)：</translation>
    </message>
    <message>
        <source>Match case</source>
        <translation>匹配大小写</translation>
    </message>
    <message>
        <source>Match whole word only</source>
        <translation>全字匹配</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>查找下一个</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>全部替换</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <source>&amp;Down</source>
        <translation>下一个(&amp;D)</translation>
    </message>
    <message>
        <source>Match whole &amp;word only</source>
        <translation>全字匹配(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Up</source>
        <translation>上一个(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Match case</source>
        <translation>匹配大小写(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Find:</source>
        <translation>查找(&amp;F)</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>查找下一个(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <source>425</source>
        <translation>425</translation>
    </message>
</context>
<context>
    <name>GetPassphraseDialog</name>
    <message>
        <source>Passphrase</source>
        <translation>口令</translation>
    </message>
    <message>
        <source>&amp;Passphrase:</source>
        <translation>口令(&amp;P)：</translation>
    </message>
    <message>
        <source>Leave blank when passphrase is not needed</source>
        <translation>如果不需要口令则留空</translation>
    </message>
</context>
<context>
    <name>GetPassphraseOrKeyDialog</name>
    <message>
        <source>Passphrase or Key File</source>
        <translation>请提供口令或者密钥文件</translation>
    </message>
    <message>
        <source>Passphrase:</source>
        <translation>口令：</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>密钥文件：</translation>
    </message>
    <message>
        <source>Leave blank when passphrase is not needed</source>
        <translation>如果不需要口令则留空</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>选择……</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>请选择密钥文件</translation>
    </message>
</context>
<context>
    <name>LoadSaveHandler</name>
    <message>
        <source>Passphrase for Key File</source>
        <translation>为密钥文件提供口令</translation>
    </message>
    <message>
        <source>Cannot open the file because it does not exist</source>
        <translation>无法打开文件，因为文件不存在</translation>
    </message>
    <message>
        <source>GPG format does not support persistent key path.</source>
        <translation>GPG格式不支持记住密钥文件路径。</translation>
    </message>
    <message>
        <source>Do you want to disable it?</source>
        <translation>你想要停用它吗？</translation>
    </message>
    <message>
        <source>GPG format does not support double protection by passphrase and key file.</source>
        <translation>GPG格式不支持口令与密钥文件的双重保护。</translation>
    </message>
    <message>
        <source>Use EPD format or disable either passphrase or key protection.</source>
        <translation>请改用EPD格式，或者停用两者之一。</translation>
    </message>
    <message>
        <source>Neither a key file nor passphrase is set. The file is going to be saved UNENCRYPTED.</source>
        <translation>你还没有设置口令或者密钥文件。文件将会不被加密的存储。</translation>
    </message>
    <message>
        <source>Neither a key file nor passphrase is set.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>ln: %1 of %2</source>
        <translation>行：%1/%2</translation>
    </message>
    <message>
        <source>chars: %1</source>
        <translation>字符：%1</translation>
    </message>
    <message>
        <source>Passphrase not set</source>
        <translation>未设置口令</translation>
    </message>
    <message>
        <source>Passphrase protected</source>
        <translation>口令保护的</translation>
    </message>
    <message>
        <source>Cannot open &apos;%1&apos;</source>
        <translation>无法打开%1</translation>
    </message>
    <message>
        <source>Cannot open the encryption key</source>
        <translation>无法打开密钥文件</translation>
    </message>
    <message>
        <source>The encryption key is invalid</source>
        <translation>密钥不合法</translation>
    </message>
    <message>
        <source>Cannot download the encryption key. CURL tool is not found.</source>
        <translation>无法读取密钥文件。没有找到CURL工具。</translation>
    </message>
    <message>
        <source>Cannot download the key. CURL returned non zero exit code</source>
        <translation>无法读取密钥。CURL的返回值不为0（发生异常）。</translation>
    </message>
    <message>
        <source>Cannot load the file</source>
        <translation>无法加载文件</translation>
    </message>
    <message>
        <source>File loaded</source>
        <translation>文件已加载</translation>
    </message>
    <message>
        <source>The file has been modified by another program. Do you want to reload it?</source>
        <translation>文件已在其他程序中被更改。你想要重新加载它吗？</translation>
    </message>
    <message>
        <source>The file has been modified by another program. Do you want to reload it and lose the changes made in this application?</source>
        <translation>文件已在其他程序中被更改。你想要重新加载它并丢弃所做的更改吗？</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>另存为</translation>
    </message>
    <message>
        <source>Cannot create the repository directory in HOME</source>
        <translation>无法在HOME中创建仓库目录</translation>
    </message>
    <message>
        <source>Passphrase for Key File</source>
        <translation>密钥文件的口令</translation>
    </message>
    <message>
        <source>You left the passphrase blank. The key file is going to be UNENCRYPTED. Do you want to continue?</source>
        <translation>你还没有设置口令。密钥文件将会不被加密的存储。确认要继续吗？</translation>
    </message>
    <message>
        <source>Cannot generate the key &apos;%1&apos; Check the path and permissions.</source>
        <translation>无法生成密钥%1；请检查路径是否正确与是否有权访问该路径。</translation>
    </message>
    <message>
        <source>Cannot generate key</source>
        <translation>无法生成密钥</translation>
    </message>
    <message>
        <source>Do you want to use the generated key for this file?</source>
        <translation>你想要为这个文件使用生成的密钥吗？</translation>
    </message>
    <message>
        <source>About EncryptPad</source>
        <translation>关于EncryptPad</translation>
    </message>
    <message>
        <source>&lt;b&gt;EncryptPad %1 Beta&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;A minimalist secure text editor and file encryptor that implements RFC 4880 Open PGP format: symmetrically encrypted, compressed and integrity protected. The editor can protect files with passphrases, key files or both.&lt;br/&gt;&lt;br/&gt;%2&lt;br/&gt;GNU General Public License v2&lt;br/&gt;&lt;br/&gt;</source>
        <oldsource>&lt;b&gt;EncryptPad %1 Beta&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;Minimalist secure text editor and binary encryptor that implements RFC 4880 Open PGP format: symmetrically encrypted, compressed and integrity protected. The editor can protect files with passphrases, key files or both.&lt;br/&gt;&lt;br/&gt;%2&lt;br/&gt;GNU General Public License v2&lt;br/&gt;&lt;br/&gt;</oldsource>
        <translation>&lt;b&gt;EncryptPad %1 Beta&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;极简的加密文本编辑器。支持RFC 4880 Open PGP格式。支持使用口令和/或密钥文件进行加密。&lt;br/&gt;&lt;br/&gt;%2&lt;br/&gt;GNU General Public License v2&lt;br/&gt;&lt;br/&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br/&gt;&lt;br/&gt;OpenPGP implementation.&lt;br/&gt;&lt;br/&gt;%2&lt;br/&gt;Simplified BSD License&lt;br/&gt;&lt;br/&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you want to apply the modified default file properties to this file?</source>
        <translation>你想要应用已修改的默认文件属性到这个文件吗？</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建(&amp;N)</translation>
    </message>
    <message>
        <source>Create a new file</source>
        <translation>创建一个新的文件</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>打开(&amp;O)……</translation>
    </message>
    <message>
        <source>Open an existing file</source>
        <translation>打开一个存在的文件</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <source>Save the document to disk</source>
        <translation>将文件保存到磁盘</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>另存为(&amp;A)</translation>
    </message>
    <message>
        <source>Save the document under a new name</source>
        <translation>将文件保存到另一个地方</translation>
    </message>
    <message>
        <source>File &amp;Properties...</source>
        <translation>文件属性(&amp;P)……</translation>
    </message>
    <message>
        <source>Set file properties</source>
        <translation>更改文件的属性</translation>
    </message>
    <message>
        <source>&amp;Close and Reset</source>
        <translation>关闭并重置(&amp;C)</translation>
    </message>
    <message>
        <source>Close and reset security settings</source>
        <translation>关闭并重置安全设置</translation>
    </message>
    <message>
        <source>Generate Key...</source>
        <translation>生成密钥……</translation>
    </message>
    <message>
        <source>Generate a new key file</source>
        <translation>生成一个新的密钥文件</translation>
    </message>
    <message>
        <source>Set &amp;Passphrase...</source>
        <translation>设置口令(&amp;P)……</translation>
    </message>
    <message>
        <source>Set passphrase for encryption and decryption</source>
        <translation>为加密与解密设置口令</translation>
    </message>
    <message>
        <source>Set &amp;Encryption Key...</source>
        <translation>设置密钥文件(&amp;E)……</translation>
    </message>
    <message>
        <source>Set encryption key file</source>
        <translation>就是设置密钥文件</translation>
    </message>
    <message>
        <source>Clear &amp;Encryption Key</source>
        <translation>清除密钥(&amp;E)</translation>
    </message>
    <message>
        <source>Clear encryption key file. Passphrase only (if set).</source>
        <translation>清除用于加密的密钥文件。这将只使用口令保护（如果设置的话）。</translation>
    </message>
    <message>
        <source>&amp;Clear Passphrase</source>
        <translation>清除口令(&amp;C)</translation>
    </message>
    <message>
        <source>Save without passphrase protected encryption. Encryption with file key only (if enabled).</source>
        <translation>停用口令保护。这将仅使用密钥文件来加密（如果启用的话）。</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>退出(&amp;X)</translation>
    </message>
    <message>
        <source>Exit the application</source>
        <translation>关闭程序</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>还原</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>剪切(&amp;U)</translation>
    </message>
    <message>
        <source>Cut the current selection&apos;s contents to the clipboard</source>
        <translation>将选定内容剪切到剪贴板</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>复制(&amp;C)</translation>
    </message>
    <message>
        <source>Copy the current selection&apos;s contents to the clipboard</source>
        <translation>将选定内容复制到剪贴板</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>粘贴(&amp;P)</translation>
    </message>
    <message>
        <source>Paste the clipboard&apos;s contents into the current selection</source>
        <translation>将剪贴板内容粘贴到当前选定范围</translation>
    </message>
    <message>
        <source>&amp;Select All</source>
        <translation>全选(&amp;S)</translation>
    </message>
    <message>
        <source>Select all text</source>
        <translation>选中所有文字</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>查找(&amp;F)</translation>
    </message>
    <message>
        <source>Find in text</source>
        <translation>在文件内查找</translation>
    </message>
    <message>
        <source>&amp;Go to...</source>
        <translation>跳转到(&amp;G)……</translation>
    </message>
    <message>
        <source>Go to</source>
        <translation>跳转到</translation>
    </message>
    <message>
        <source>&amp;Generate Passphrase...</source>
        <translation>生成口令(&amp;G)……</translation>
    </message>
    <message>
        <source>Generate passphrase</source>
        <translation>生成随机口令</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>替换(&amp;R)……</translation>
    </message>
    <message>
        <source>Find and replace text</source>
        <translation>查找并替换文本</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>只读</translation>
    </message>
    <message>
        <source>Enable Read Only mode</source>
        <translation>启用只读模式</translation>
    </message>
    <message>
        <source>Word Wrap</source>
        <translation>自动换行</translation>
    </message>
    <message>
        <source>Enable Word Wrap</source>
        <translation>启用自动换行</translation>
    </message>
    <message>
        <source>&amp;Zoom In</source>
        <translation>放大(&amp;Z)</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>&amp;Zoom Out</source>
        <translation>缩小(&amp;Z)</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>缩小</translation>
    </message>
    <message>
        <source>&amp;Reset Zoom</source>
        <translation>重置缩放(&amp;R)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>重置缩放</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>关于(&amp;A)……</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>显示程序的「关于」对话框</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于Qt(&amp;Q)</translation>
    </message>
    <message>
        <source>Show the Qt library&apos;s About box</source>
        <translation>显示Qt的「关于」对话框</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>首选项(&amp;P)……</translation>
    </message>
    <message>
        <source>Application preferences</source>
        <translation>程序首选项</translation>
    </message>
    <message>
        <source>File Encryption...</source>
        <translation>文件加密...</translation>
    </message>
    <message>
        <source>File encryption</source>
        <translation>文件加密</translation>
    </message>
    <message>
        <source>Windows EOL</source>
        <translation>使用Windows换行风格</translation>
    </message>
    <message>
        <source>&quot;Windows&quot; end of line: CR+LF</source>
        <translation>使用Windows换行风格：CR+LF</translation>
    </message>
    <message>
        <source>End of file reached. Started from the top.</source>
        <translation>已经到达了文件末尾。将会从头开始。</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>没有找到文本。</translation>
    </message>
    <message>
        <source>Text found.</source>
        <translation>发现了文本。</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>视图(&amp;V)</translation>
    </message>
    <message>
        <source>En&amp;cryption</source>
        <translation>加密(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>设置(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>View</source>
        <translation>视图</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>就绪</translation>
    </message>
    <message>
        <source>The document has been modified.</source>
        <translation>文件已被更改。</translation>
    </message>
    <message>
        <source>Do you want to save your changes?</source>
        <translation>你想要保存文件吗？</translation>
    </message>
    <message>
        <source>Cannot save &apos;%1&apos;</source>
        <translation>无法保存%1</translation>
    </message>
    <message>
        <source>Cannot open the specified encryption key</source>
        <translation>无法打开指定的密钥文件</translation>
    </message>
    <message>
        <source>The specified encryption key is invalid</source>
        <translation>指定的密钥文件不合法</translation>
    </message>
    <message>
        <source>Cannot download the encryption key. CURL tool is not found</source>
        <translation>无法读取密钥文件。没有找到CURL工具。</translation>
    </message>
    <message>
        <source>Cannot download the encryption key. CURL returned non zero exit code</source>
        <translation>无法读取密钥文件。CURL的返回值不为0（发生异常）</translation>
    </message>
    <message>
        <source>Unknown encryption error</source>
        <translation>未知加密错误</translation>
    </message>
    <message>
        <source>Cannot create bak file</source>
        <translation>无法创建备份文件</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>Cannot save file</source>
        <translation>无法保存文件</translation>
    </message>
    <message>
        <source>File saved</source>
        <translation>文件已保存</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>行号：</translation>
    </message>
    <message>
        <source>Maximum zoom</source>
        <translation>最大缩放</translation>
    </message>
    <message>
        <source>Font size: %1</source>
        <translation>文本大小：%1</translation>
    </message>
    <message>
        <source>Minimum zoom</source>
        <translation>最小缩放</translation>
    </message>
    <message>
        <source>Font size: </source>
        <translation>字号：</translation>
    </message>
    <message>
        <source>untitled</source>
        <translation>无标题</translation>
    </message>
    <message>
        <source>Key protected</source>
        <translation>密钥保护的</translation>
    </message>
    <message>
        <source>Key not set</source>
        <translation>未设置密钥</translation>
    </message>
    <message>
        <source>persistent</source>
        <translation>记住</translation>
    </message>
    <message>
        <source>options:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;--lang&lt;/b&gt; - to enforce the language for the GUI</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;--log-file&lt;/b&gt; - specify the log file for diagnostics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;b&gt;--log-severity&lt;/b&gt; - log severity can be one of the following list: none, fatal, error, warning, info, debug, verbose</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Command Line Interface</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>encryptpad[.exe] [options] [file]</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NewKeyDialog</name>
    <message>
        <source>Generate Key</source>
        <translation>生成密钥</translation>
    </message>
    <message>
        <source>&amp;Key path</source>
        <translation>密钥路径(&amp;K)</translation>
    </message>
    <message>
        <source>Key in &amp;repository</source>
        <translation>仓库中的密钥(&amp;R)</translation>
    </message>
    <message>
        <source>Key path</source>
        <translation>密钥路径</translation>
    </message>
    <message>
        <source>The repository is &lt;b&gt;.encryptpad&lt;/b&gt; directory in the user&apos;s profile (&lt;b&gt;encryptpad_repository&lt;/b&gt; in portable mode).</source>
        <translation>EncryptPad仓库即用户文件夹内的&lt;b&gt;.encryptpad&lt;/b&gt;，（便携版EncryptPad则为EncryptPad目录内的&lt;b&gt;encryptpad_repository&lt;/b&gt;）</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>浏览……</translation>
    </message>
    <message>
        <source>Key name in the repository</source>
        <translation>仓库中的密钥名称</translation>
    </message>
    <message>
        <source>Save New Key To</source>
        <translation>将新的密钥保存到</translation>
    </message>
    <message>
        <source>Invalid characters in the key name</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PassphraseGenerationDialog</name>
    <message>
        <source>Generate Passphrase</source>
        <translation>生成口令</translation>
    </message>
    <message>
        <source>Custom:</source>
        <translation>自定义：</translation>
    </message>
    <message>
        <source>Lowercase a-z</source>
        <translation>小写a-z</translation>
    </message>
    <message>
        <source>Numbers 0-9</source>
        <translation>数字0-9</translation>
    </message>
    <message>
        <source>Symbols:</source>
        <translation>符号：</translation>
    </message>
    <message>
        <source>` ~ ! @ # $ % ^ &amp; * ( ) _ - + = { } [ ]  | : ; &quot; &apos; &lt; &gt; , . ? /</source>
        <translation>` ~ ! @ # $ % ^ &amp; * ( ) _ - + = { } [ ]  | : ; &quot; &apos; &lt; &gt; , . ? /</translation>
    </message>
    <message>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <source>Uppercase A-Z</source>
        <translation>大写A-Z</translation>
    </message>
    <message>
        <source>&amp;Regenerate</source>
        <translation>重新生成(&amp;R)</translation>
    </message>
    <message>
        <source>Insert &amp;all</source>
        <translation>插入全部(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Length:</source>
        <translation>长度(&amp;L)：</translation>
    </message>
    <message>
        <source>Select &amp;passphrase:</source>
        <translation>选择口令(&amp;P)：</translation>
    </message>
    <message>
        <source>Limit group occurrence (1 to max chars)</source>
        <translation>限制组合出现次数（不小于1）</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>组合</translation>
    </message>
    <message>
        <source>Regenerate</source>
        <translation>重新生成</translation>
    </message>
    <message>
        <source>7 passphrases</source>
        <translation>7个口令</translation>
    </message>
    <message>
        <source>15 passphrases</source>
        <translation>15个口令</translation>
    </message>
    <message>
        <source>25 passphrases</source>
        <translation>25个口令</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>首选项</translation>
    </message>
    <message>
        <source>Libcurl command line parameters</source>
        <translation>Libcurl 命令行参数</translation>
    </message>
    <message>
        <source>Parameters:</source>
        <translation>参数：</translation>
    </message>
    <message>
        <source>Key file encryption properties:</source>
        <translation>密钥文件加密属性：</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>字体：</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>浏览……</translation>
    </message>
    <message>
        <source>Create .bak files</source>
        <translation>启用备份文件(.bak)</translation>
    </message>
    <message>
        <source>[example: Monospace (Size: 12)]</source>
        <translation>[example: Monospace (Size: 12)]</translation>
    </message>
    <message>
        <source>Save last used directory</source>
        <translation>保存最近使用的目录</translation>
    </message>
    <message>
        <source>Word wrap</source>
        <translation>自动换行</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Libcurl path:</source>
        <translation>libcurl路径：</translation>
    </message>
    <message>
        <source>Recent files:</source>
        <translation>最近使用的文件：</translation>
    </message>
    <message>
        <source>Default file properties:</source>
        <translation>默认文件属性：</translation>
    </message>
    <message>
        <source>This controls how many times you can save without entering a passphrase</source>
        <translation>这决定了你在不再次输入口令的情况下可以保存多少次</translation>
    </message>
    <message>
        <source>S2K derivations from a passphrase:</source>
        <oldsource>Passphrase to key results pool size:</oldsource>
        <translation>从口令生成的S2K衍生结果：</translation>
    </message>
    <message>
        <source>Key file random sequence length (bytes):</source>
        <translation>密钥文件随机序列长度（字节数）：</translation>
    </message>
    <message>
        <source>Enable FakeVim (restart required)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <source>64</source>
        <translation>64</translation>
    </message>
    <message>
        <source>128</source>
        <translation>128</translation>
    </message>
    <message>
        <source>256</source>
        <translation>256</translation>
    </message>
    <message>
        <source>Display line numbers</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;Windows&quot; end of line: CR+LF</source>
        <translation>使用Windows换行风格：CR+LF</translation>
    </message>
    <message>
        <source>Tab size:</source>
        <translation>制表符大小: </translation>
    </message>
    <message>
        <source>Retain last used directory between EncryptPad sessions</source>
        <translation>在进程间保留最近使用的目录</translation>
    </message>
    <message>
        <source>Path to libCURL executable</source>
        <translation>libCURL可执行文件路径</translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>字体……</translation>
    </message>
    <message>
        <source>(Size: </source>
        <translation>(大小: </translation>
    </message>
    <message>
        <source>)</source>
        <translation>）</translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation>选择字体</translation>
    </message>
    <message>
        <source>Path to Libcurl</source>
        <translation>libcurl路径</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <source>Information</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SetKeyDialog</name>
    <message>
        <source>Set Encryption Key</source>
        <translation>设置密钥</translation>
    </message>
    <message>
        <source>Key &amp;repository:</source>
        <translation>密钥仓库(&amp;R)：</translation>
    </message>
    <message>
        <source>&amp;Browse...</source>
        <translation>浏览(&amp;B)：</translation>
    </message>
    <message>
        <source>&amp;Key file path:</source>
        <translation>密钥文件路径(&amp;K)：</translation>
    </message>
    <message>
        <source>&amp;Persistent key location in the encrypted file</source>
        <translation>记住密钥位置(&amp;P)</translation>
    </message>
    <message>
        <source>The repository is &lt;b&gt;.encryptpad&lt;/b&gt; directory in the user&apos;s profile (&lt;b&gt;encryptpad_repository&lt;/b&gt; in portable mode). Select a key or specify a file name without path for the repository keys.</source>
        <translation>如果要指定一个在EncryptPad仓库（安装版Encryptpad的话为用户文件夹内的&lt;b&gt;.encryptpad&lt;/b&gt;，便携版则为EncryptPad目录内的&lt;b&gt;encryptpad_repository&lt;/b&gt;）内的密钥，可以省略密钥文件的路径。</translation>
    </message>
    <message>
        <source>Specify encryption key location</source>
        <translation>指定密钥路径</translation>
    </message>
</context>
<context>
    <name>SetPassphraseDialog</name>
    <message>
        <source>&amp;Passphrase:</source>
        <translation>口令(&amp;P)：</translation>
    </message>
    <message>
        <source>&amp;Confirmation:</source>
        <translation>确认口令(&amp;C)：</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>确定(&amp;O)：</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Set Passphrase</source>
        <translation>设置口令</translation>
    </message>
    <message>
        <source>The confirmation passphrase does not match</source>
        <translation>两次输入的口令不一致</translation>
    </message>
</context>
</TS>